1. Building a simple blog — CubicWeb 3.10.1

### Navigation

- index
- modules |
- next |
- previous |
- CubicWeb 3.10.1 »
- Tutorials »

# 1. Building a simple blog

CubicWeb is a semantic web application framework that favors reuse and object-oriented design.

A cube is a component that includes a model defining the data types and a set of views to display the data. A cube can be built by assembling other cubes.

An instance is a specific installation of a cube and includes configuration files.

This tutorial will show how to create a cube and how to use it as an application to run an instance.

- 1.1. Get a blog running in five minutes!
  - 1.1.1. Permission
  - 1.1.2. Instance parameters
- 1.2. Steps for creating your cube
- 1.3. Create your cube
- 1.4. Define your data model
- 1.5. Create and explore your instance
  - 1.5.1. Create your instance
  - 1.5.2. Welcome to your web instance
  - 1.5.3. Add entities
- 1.6. Define your entity views
  - 1.6.1. The view selection principle
  - 1.6.2. Primary view customization
- 1.7. Write entities to add logic in your data
- 1.8. Updating the schema and synchronising the instance
- 1.9. Cubes
  - 1.9.1. Standard library
  - 1.9.2. Adding comments to BlogDemo
  - 1.9.3. Synchronize the data model
- 1.10. Templates
  - 1.10.1. Customize a template
- 1.11. What’s next?

### Navigation

- index
- modules |
- next |
- previous |
- CubicWeb 3.10.1 »
- Tutorials »